==> keycloak-model-map-hot-rod-19.0.0-sources.jar: org/keycloak/models/map/storage/hotRod/singleUseObject/HotRodSingleUseObjectEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.singleUseObject;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
public class HotRodSingleUseObjectEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntity, org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.models.ActionTokenValueModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.models.ActionTokenValueModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntity, org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntity.HotRodSingleUseObjectEntitySchema.INSTANCE;
    }
}

==> keycloak-model-map-hot-rod-20.0.2-sources.jar: org/keycloak/models/map/storage/hotRod/singleUseObject/HotRodSingleUseObjectEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.singleUseObject;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
public class HotRodSingleUseObjectEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntity, org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.models.SingleUseObjectValueModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.models.SingleUseObjectValueModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntity, org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.singleUseObject.HotRodSingleUseObjectEntity.HotRodSingleUseObjectEntitySchema.INSTANCE;
    }
}
